<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Lối tắt bị ẩn</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Những lối tắt (shorcut) mặc định sẽ được ghi đè (thay đổi), nếu những lối tắt này được gán vào những tác vụ (chương trình) khác trong: Tham chiếu -&gt; Lối tắt.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Lối tắt</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Thực hiện</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Đóng cửa sổ hoặc thoát khỏi chế độ toàn màn hình</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Bên phải</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Hình tiếp theo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Khoảng trống (Space)</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Kết thúc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Hình cuối cùng</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Bên trái</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Hình trước đó</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Xóa trái</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Gốc (Home)</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Hình đầu tiên</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="93"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Chạy đầy màn hình (hữu ích với trình quản lý cửa sổ dạng ô)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Chụp ảnh màn hình (không dùng nữa, vui lòng dùng screengrab thay thế)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Chụp ảnh màn hình và lưu vào thư mục mà không thông qua GUI (không dùng nữa, vui lòng dùng screengrab thay thế)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="116"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[tập_tin1, tập_tin2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>phản hồi không rõ lỗi</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>phản hồi lỗi không rõ</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Về</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Trình xem ảnh đơn giản và nhanh chóng</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Bản quyền (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>Dự án LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Phát triển: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Tác giả: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Mở Tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Tập tin ảnh (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Mở thư mục</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Lưu Tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Đang tải...) - Trình xem Ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Tải Thất bại) - Trình xem Ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Trình xem Ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Trình xem Ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Hình thu nhỏ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>Dữ liệu EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>Xóa (&amp;C)</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Sử dụng một khóa chỉnh sửa để xóa một lối tắt
trong chế độ chỉnh sửa.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>Bên dưới</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>Bên trên</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Bên trái</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Cảnh báo: Lối tắt thiếu rõ ràng được phát hiện!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Lối tắt thiếu rõ ràng không được chấp nhận.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Không thể lưu bằng dạng ảnh này!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Kích cỡ:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Đường dẫn:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Ngừng</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Đóng</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Lỗi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Trình xem ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Tập tin được mở gần đây (&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>Thông tin (&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Annotations Toolbar</source>
        <translation>Chú giải thanh công cụ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Mở bằng (&amp;W)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Sắp xếp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Lối tắt ẩn (&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>Mở (&amp;O)…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>Mở lại Tập tin (&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>Lưu lại (&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Lưu nơi khác (&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>Đóng (&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Phóng to (&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>Thu nhỏ (&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Chép vào Bộ nhớ đệm (&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Tập tin Tiếp theo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Tập tin trước</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Kích thước gốc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>Vừa khớp (&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Xoay Theo chiều Đồng hồ (&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Xoay Ngược chiều Đồng hồ (&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>Tùy chọn (&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>&amp;Print</source>
        <translation>In (&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>First File</source>
        <translation>Tập tin đầu tiên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Last File</source>
        <translation>Tập tin cuối</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>&amp;New Window</source>
        <translation>Cửa sổ mới (&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Lật ngang (&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>Capture Screenshot</source>
        <translation>Chụp màn hình</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>F&amp;ull Screen</source>
        <translation>Toàn màn hình (&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Flip &amp;Vertically</source>
        <translation>Lật dọc (&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Dán từ Bộ nhớ đệm (&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>&amp;Slide Show</source>
        <translation>Trình chiếu (&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>&amp;Delete</source>
        <translation>Xóa (&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Show Thumbnails</source>
        <translation>Hiện ảnh thu nhỏ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>File Properties</source>
        <translation>Thuộc tính tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="562"/>
        <source>Open &amp;Directory</source>
        <translation>Mở thư mục (&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>Upload</source>
        <translation>Tải lên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Upload the image</source>
        <translation>Tải lên hình ảnh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Show EXIF Data</source>
        <translation>Hiện dữ liệu EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>No Tool</source>
        <translation>Không có công cụ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Deselect all drawing tools</source>
        <translation>Bỏ chọn tất cả công cụ vẽ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="615"/>
        <source>Draw Arrow</source>
        <translation>Vẽ mũi tên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Draw an arrow</source>
        <translation>Vẽ một mũi tên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="630"/>
        <source>Draw Rectangle</source>
        <translation>Vẽ hình chữ nhật</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="633"/>
        <source>Draw a hollow rectangle</source>
        <translation>Vẽ hình chữ nhật rỗng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Draw Circle</source>
        <translation>Vẽ hình tròn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>Draw a hollow circle</source>
        <translation>Vẽ hình tròn rỗng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Draw Number</source>
        <translation>Vẽ số</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Draw incrementing numbers</source>
        <translation>Vẽ các số tăng dần</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Menubar</source>
        <translation>Thanh ứng dụng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>&amp;Main Toolbar</source>
        <translation>Thanh công cụ chính (&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="688"/>
        <source>Main Toolbar</source>
        <translation>Thanh công cụ chính</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>Thanh công cụ chú thích (&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <location filename="../mainwindow.ui" line="710"/>
        <source>Show Outline</source>
        <translation>Hiện đường viền</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="721"/>
        <source>Copy Pa&amp;th</source>
        <translation>Chép đường dẫn (&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Copy path</source>
        <translation>Chép đường dẫn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Rename</source>
        <translation>Đổi tên</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Resize</source>
        <translation>Đổi kích thước</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>&amp;By File Name</source>
        <translation>Theo Tên Tập tin (&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>By File Name</source>
        <translation>Theo Tên Tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="766"/>
        <source>By &amp;Modification Time</source>
        <translation>Theo Thời gian Sửa đổi (&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>By Modification Time</source>
        <translation>Theo Thời gian Sửa đổi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="777"/>
        <source>By C&amp;reation Time</source>
        <translation>Theo Thời gian Tạo (&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>By Creation Time</source>
        <translation>Theo Thời gian Tạo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="788"/>
        <source>By File &amp;Size</source>
        <translation>Theo Kích thước Tập tin (&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>By File Size</source>
        <translation>Theo Kích thước Tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="799"/>
        <source>By File &amp;Type</source>
        <translation>Theo Kiểu Tập tin (&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="802"/>
        <source>By File Type</source>
        <translation>Theo Kiểu Tập tin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>Tập tin (&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>Trợ giúp (&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Đi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>Xem (&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>Chỉnh sửa (&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Thanh công cụ</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Tham chiếu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Giao diện biểu tượng:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Giới hạn kích thước tập tin hình thu nhỏ:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Màu nền thông thường:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Màu nền toàn màn hình:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Số lượng tối đa những tập tin gần đây:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Thời gian trình chiếu (giây):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Hiện viền hình mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Hiện chú thích thanh công cụ mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Làm vừa hình khi điều hướng</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Kích thước hình thu nhỏ:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Dùng Thùng rác hệ thống (và không hỏi lại)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Cửa sổ</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Hiện khay hình thu nhỏ mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Hiện khay dữ liệu Exif mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Hiện thanh ứng dụng mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Hiện thanh công cụ chính mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Chỉ có thể hoạt động với những hình ảnh có không gian màu hợp lệ.
Tải lại hình ảnh hiện tại để xem hiệu ứng.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Không gian màu:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (được hầu hết các màn hình hỗ trợ)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>sRGB tuyến tính (gamma tuyến tính)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (màn hình gam màu rộng)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Phóng to/thu nhỏ hình ảnh mượt mà</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Lối tắt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Lối tắt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Tổng quan</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="996"/>
        <source>Error</source>
        <translation>Lỗi</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Đổi kích cỡ hình</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Rộng</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Cao</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Kích cỡ hiện tại:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Kích cỡ mới:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Giữ tỉ lệ</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Ảnh chup màn hình</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Chụp màn hình</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Vùng</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Chỉ cửa sổ hiện hành</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Chụp một vùng màn hình</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Gồm con trỏ</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> giây</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Độ trễ:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Gồm khung và ô cửa sổ</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Tải lên</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Chép</translation>
    </message>
</context>
</TS>
